# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn22.06

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 22.06.0
Release: 273%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/v%{version}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit 55ee005bef94566fe829b667960d7bb9ac925974
%define ovsshortcommit 55ee005

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%autosetup -n ovn-%{version} -a 10 -p 1

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Tue Jan 21 2025 Numan Siddique <numans@ovn.org> - 22.06.0-271
- Skip only OVN DNS responder packets from OUT_ACL.
[Upstream: 4faf7f8381f6c24e7f78da282b31a1cb26e7a29b]

* Fri Oct 18 2024 Vladislav Odintsov <vlodintsov@k2.cloud> - 22.06.0-270
- ovs: Bump submodule to OVS v3.0.7.
[Upstream: f50f3ae2d1271a129a79fa25258cfa5a19b647e8]

* Wed Mar 13 2024 Mohammad Heib <mheib@redhat.com> - 22.06.0-269
- controller: Release container lport when releasing parent port.
[Upstream: f7c4af76a2434d49be9650405ab05b3806e991d3]

* Tue Mar 12 2024 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-268
- github: Reduce ASLR entropy to be compatible with asan in llvm 14.
[Upstream: 65e0bf71685f5f0b2a613ca838cc1df4812105f5]

* Tue Mar 12 2024 Frode Nordahl <frode.nordahl@canonical.com> - 22.06.0-267
- controller: Set check_tnl_key for BFD on tunnel ifaces.
[Upstream: bbba592dea6b656afb39f5c4d982c7aadeb9675a]

* Fri Mar 08 2024 Dumitru Ceara <dceara@redhat.com> - 22.06.0-266
- tests: Skip EDNS test if the scapy version doesn't support it.
[Upstream: 713553bc26c8db699f8868f0b359c04631082a87]

* Wed Mar 06 2024 Dumitru Ceara <dceara@redhat.com> - 22.06.0-265
- northd: Don't skip the unSNAT stage for traffic towards VIPs. (#FDP-291)
[Upstream: d8eb6e2a311eee4f64df6cb95b639c7b120c06ef]

* Mon Feb 12 2024 Dumitru Ceara <dceara@redhat.com> - 22.06.0-264
- pinctrl: dns: Ignore additional records. (#FDP-222)
[Upstream: fb5ff5986fd3cab8e5a7353f4ffe591f2f90a644]

* Mon Feb 12 2024 Roberto Bartzen Acosta <roberto.acosta@luizalabs.com> - 22.06.0-263
- ovn-ic: Fix global blacklist filter for IPv6 addresses.
[Upstream: cf272b89fee47b6db155a1f6fa6867d83d0e83d2]

* Mon Feb 12 2024 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-262
- tests: Fix macro OVN_CHECK_PACKETS_CONTAIN.
[Upstream: 257d00bd95f577ea26900fda6042046a80f4330e]

* Fri Feb 09 2024 Nobuhiro MIKI <nmiki@yahoo-corp.jp> - 22.06.0-261
- Documentation: Fix broken links in ovn-sandbox.rst.
[Upstream: 3703300680b67f01fd6f98535bfd9ede5bcf19d9]

* Fri Feb 09 2024 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-260
- github: Update versions of action dependencies (Node.js 20).
[Upstream: 85e9345fbe34bf11f33fc92eb3378d7e61dc7574]

* Thu Feb 08 2024 Ales Musil <amusil@redhat.com> - 22.06.0-259
- northd: Remove the protocol match from ECMP symmetric reply flows. (#FDP-358)
[Upstream: 155f27b08837edc40c3ac91e24c3b29d8d3e5a66]

* Tue Jan 30 2024 Dumitru Ceara <dceara@redhat.com> - 22.06.0-258
- actions: Use random port selection for SNAT with external_port_range. (#FDP-301)
[Upstream: db773f3450f60d3e0116b54e7cd3c094074100d8]

* Tue Jan 30 2024 Mohammad Heib <mheib@redhat.com> - 22.06.0-257
- ovn-ic: Handle NB:name updates properly.
[Upstream: 7d6571d53ca5b604c406a98843b4e808a0fe400f]

* Tue Jan 23 2024 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-256
- controller: fixed potential segfault when changing tunnel_key and deleting ls.
[Upstream: 35d609f3f0d4ba899f614950350d5b69387ba80a]

* Fri Jan 19 2024 Ales Musil <amusil@redhat.com> - 22.06.0-255
- northd: Use proper field for lookup_nd (#FDP-283)
[Upstream: 6241d8c0fd04deb327eb82f07255a78429e53479]

* Thu Jan 11 2024 Mark Michelson <mmichels@redhat.com> - 22.06.0-254
- pinctrl: Directly retrieve desired port_binding MAC. (#FDP-224)
[Upstream: 8a29bf82ce89ef24c30ed748e637f1e53e0ef3a6]

* Tue Jan 09 2024 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-253
- test: add dedicated test for garp-max-timeout
[Upstream: 176b6fc7cf3513ff8647903a1c9d4739aabaf74e]

* Tue Jan 09 2024 Ales Musil <amusil@redhat.com> - 22.06.0-252
- treewide: Fix small memory leaks reported by static analysis
[Upstream: ccf42d27ae1d9a883c38755902ea8cec64794ee2]

* Tue Jan 09 2024 Dumitru Ceara <dceara@redhat.com> - 22.06.0-251
- ovs: Bump submodule to include IDL "spurious delete" fix.
[Upstream: a393da156f46f09e10fffc83549b6d85e8abb582]

* Wed Jan 03 2024 Jacob Tanenbaum <jtanenba@redhat.com> - 22.06.0-250
- Correct ethtype referencing incorrect values
[Upstream: ebe16bcdb661592478f6127ef5bcd14a00d56a7b]

* Mon Dec 18 2023 Daniel Ding <danieldin186@gmail.com> - 22.06.0-249
- northd: forward arp request to lrp snat on.
[Upstream: 567bb4a37d1229984fd8b15a0dd72b492db22f79]

* Thu Dec 07 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-248
- controller: make garp_max_timeout configurable
[Upstream: 65be1cb1e9dc0f3bb874e32684680e43a192a4a6]

* Thu Dec 07 2023 Ales Musil <amusil@redhat.com> - 22.06.0-247
- system-tests: Consolidate wait condition in CoPP test
[Upstream: 888f7bf9ce3ae014f4ee90f51ce50e7c0706e3b9]

* Thu Dec 07 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-246
- pinctrl: Fix up comments about sending RST packets for healthcheck.
[Upstream: cf6f84d0db2d4b08ecbe121f53a2512933f85dd8]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-245
- fmt_pkt: make sure scapy-server is started once
[Upstream: 42770610afc5dc863a9e6c768eef861789369cdc]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-244
- fmt_pkt: improve scapy-server logging
[Upstream: 2734879274c571bf782c14acad11bc63e650dd4a]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-243
- fmt_pkt: use -S check to wait for scapy sock file
[Upstream: 964056f5f1375a24767dfe3f23344bda94ab1532]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-242
- fmt_pkt: don't subshell when calling ovs-appctl
[Upstream: 347f17874921e1a88b705a23f0060ae0c54bddcf]

* Mon Dec 04 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-241
- controller: fix group_table and meter_table allocation
[Upstream: 8737b534fa0718626e882183400d7f0f987560d1]

* Mon Nov 20 2023 Evgenii Kovalev <ekovalev.off@gmail.com> - 22.06.0-240
- pinctrl: reset success and failures n_count regardless of svc state
[Upstream: e20b9ffddc95cc52a69c1026c9ccc279826e6dff]

* Mon Nov 20 2023 Evgenii Kovalev <ekovalev.off@gmail.com> - 22.06.0-239
- pinctrl: send RST instead of RST_ACK bit for lb hc
[Upstream: 9dba9136d11a576b22931ee4e1258ff385be57b7]

* Mon Nov 20 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-238
- controller: Don't artificially limit group and meter IDs to 16bit. (#FDP-70)
[Upstream: 84d065c8d5d2fa866b136d54839d630fb84d55d6]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-237
- tests: fixed race_condition with max_prefix
[Upstream: 00c11d63f41234b77ce86f5de2983eb0aecb00d2]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-236
- tests: fixed "ovn-nbctl - daemon retry connection"
[Upstream: 407b47affbd15f65ec60d4a2b65c7a7fd04460ab]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-235
- tests: fixed system test "LR with SNAT fragmentation needed for external server".
[Upstream: 068d8fb7d389474f29e6d6eb3758c4c7794e48a0]

* Fri Nov 17 2023 martin.kalcok@canonical.com <martin.kalcok@canonical.com> - 22.06.0-234
- ovn-ctl man: Add election timer config to manpage
[Upstream: 2e33d354a276389447926117b538c8f3facca6b9]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-233
- controller: have I+P assigning ct_zones for l3gateway ports
[Upstream: 78719664bdd5a0e5346e3750bf036937a08a5015]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-232
- tests: fixed another set of flaky ovn-ic tests (#FDP-98)
[Upstream: adb6c2d1070797c387e62992678647143d27ecce]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-231
- tests: wait for all flows to be installed before sending packets
[Upstream: 3a0a21b080cab1c03c9260e45af25dc6ef48d98c]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-230
- tests: fixed "ipsec -- basic configuration"
[Upstream: b48f8d1c6aef0a89bff83ebefecfa83b6bb5b238]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-229
- tests: do not start backup-northd by default
[Upstream: 26bf9c4df6da739a80674752d433fe9e46add755]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-228
- tests: fixed multiple tests not properly waiting for packets to be received
[Upstream: b9b5e461ecb144a8863beccb43eae300c95561b9]

* Fri Nov 17 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-227
- ci: Pin Python, Fedora and Ubuntu runner versions.
[Upstream: 86c3753cdbd0fb7c506fc3eadf7d5f0e3203e400]

* Thu Nov 16 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-226
- ovs: Bump submodule to include E721 fixes.
[Upstream: c5a8ac38023765325d8318317a8837ef2fe440ec]

* Thu Nov 16 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-225
- tests: Remove broken "feature inactivity probe" test.
[Upstream: 3eb6e4cb47b34190321555d5f9166701bbd032c7]

* Wed Nov 15 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-224
- ovs: Bump submodule to use v3.0.5.
[Upstream: 255aff51c48f5103c106493e4cf53afe04ee75d0]

* Wed Nov 15 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-223
- py-requirements: Remove hacking dependency and use recent flake8.
[Upstream: 75bee9147fd4f12f39f63a7370cef36f4e6a0d85]

* Fri Oct 20 2023 Ales Musil <amusil@redhat.com> - 22.06.0-222
- controller, northd: Wait for cleanup before replying to exit
[Upstream: 2b5940648b6fd3376a0fc73bc24d6a4266af76e3]

* Fri Oct 20 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-221
- tests: Add missing check for scapy.
[Upstream: e8516f60268fb7ae7d676764fe0f88122e257e55]

* Tue Oct 10 2023 Ales Musil <amusil@redhat.com> - 22.06.0-220
- system-tests: Make sure that IPv6 address is available right away
[Upstream: 6ad2e493f7d49e04434c618a24b4d2418739b542]

* Tue Oct 10 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-219
- Don't mention packet cloning when failing to find tunnel
[Upstream: 24d83c68d1f7bd3935036ee810cb393e7741c0e4]

* Tue Oct 10 2023 Ales Musil <amusil@redhat.com> - 22.06.0-218
- northd: Allow need frag to be SNATed (#FDP-39)
[Upstream: 223843869ee849735b36c1eb144a34ab4fd45828]

* Tue Oct 10 2023 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-217
- memory-trim: Fix timestamp overflow warning right after reboot.
[Upstream: 33b15efa7c7b09390a53520ac25915014da74c01]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-216
- tests: fixed "send gratuitous ARP for NAT rules on HA distributed router"
[Upstream: 31a5b6167bc41ab27e0920f4b1c0ed9472a32068]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-215
- tests: move trim_zeros() to ovn-macros
[Upstream: 0c69545f0de8ce22cf483bc05be964a571bf6d3e]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-214
- tests: fixed "L2 Drop and Allow ACL w/ Stateful ACL"
[Upstream: 6f9e5dbd745ba90fcfa47b20e3d69d4ff4eecead]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-213
- tests: fixed multiple tests missing ovn-nbctl "wait"
[Upstream: 00e0689e9d1fd81862778d23b3e403f3b8aba5f7]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-212
- tests: fixed "Logical router policy packet marking"
[Upstream: 48dadc386449b1f24df0118a45d34ee4238d961c]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-211
- tests: fixed multiple ovn-ic tests
[Upstream: 66010f9785e64a26b37bd12b82c19ce3f8616790]

* Thu Oct 05 2023 Ales Musil <amusil@redhat.com> - 22.06.0-210
- pinctrl: Reply with correct destination for ICMPv6 RA packets (#FDP-43)
[Upstream: 23a4e5c30832031c9fda0c1efaaea94edcbef5cc]

* Mon Oct 02 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-209
- ovn-controller: Add monitor condition for FDB.
[Upstream: 7d4327387ab20d0f470bc6570dc3e6a11b3edfa4]

* Tue Sep 26 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-208
- northd: Drop packets destined to router owned NAT IP for DGP.
[Upstream: 122266e3d23e689f34d7c9ae4c93101c06dbcd7a]

* Thu Sep 21 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-207
- Rename scapy-server into scapy-server.py
[Upstream: d48e8662bf3a56d6200a5cd7dd7f7e4b75ed0be3]

* Wed Sep 20 2023 Patryk Diak <pdiak@redhat.com> - 22.06.0-206
- Add ovnkube-identity binary to the ovn-kubernetes Dockerfile
[Upstream: 6e6191ed50d6810c36b56a3e7d58ea49a054c8ea]

* Tue Sep 19 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-205
- tests: offload scapy transformations to a separate unixctl daemon
[Upstream: 4b37a03b6b3260c4b92731cd61922f98e81e5e29]

* Thu Sep 14 2023 Ales Musil <amusil@redhat.com> - 22.06.0-204
- ofctrl: Prevent conjunction duplication
[Upstream: 0e9cb178ebabb31b5590e6fe548d5fc6e4903e2a]

* Thu Sep 14 2023 Ales Musil <amusil@redhat.com> - 22.06.0-203
- ofctrl: Do not try to program long flows
[Upstream: aea62faf5409607b37a052278d67ab08f7944159]

* Mon Sep 11 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-202
- northd: Always ct commit ECMP symmetric traffic in the original direction.
[Upstream: 8259a33cd5315fac50624b066cde7fbe638b1298]

* Wed Sep 06 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-201
- Use correct nw_ttl=255 to match against legit NAs
[Upstream: 7084d77f4ce9e4f5c46997cca2c37025a113a405]

* Wed Sep 06 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-200
- checkpatch: Ignore yml files when checking line lengths.
[Upstream: aceb5dd4ffa1b3e9d4738f313273f89b44bdaadd]

* Wed Sep 06 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-199
- checkpatch.py: Revert previous commit.
[Upstream: 660ba4a6ffa56982e0a5dca37f30879f4bd72f25]

* Tue Aug 29 2023 Ales Musil <amusil@redhat.com> - 22.06.0-198
- northd, controller: Add CoPP for SVC monitor
[Upstream: c0f17e7d1452c35de8f3c3540b8750662742cec4]

* Tue Aug 29 2023 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-197
- northd: Fix recompute of referenced chassis in HA chassis groups.
[Upstream: 6040c4eeee8362d66147d0e9eac501cd0cbe4441]

* Fri Aug 25 2023 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-196
- northd: Fix incorrect memory allocation for router group datapaths.
[Upstream: c651042707e4275c52fdf684d536a9d89bcf38eb]

* Tue Aug 15 2023 Felix Huettner <felix.huettner@mail.schwarz> - 22.06.0-195
- fix missing documentation of ovn-ic arguments
[Upstream: 83369282896003025a375183901acfc33a74642f]

* Mon Aug 14 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-194
- ovn-controller: Assume well-known tables are in the SB schema.
[Upstream: ec9f45fa4cd85e81325303f5979775edd8f6bb07]

* Mon Aug 14 2023 Igor Zhukov <fsb4000@yandex.ru> - 22.06.0-193
- Fix a link.
[Upstream: 6b485ee535f43e8cf5234c51866a5e521fd44885]

* Wed Aug 09 2023 Mohammad Heib <mheib@redhat.com> - 22.06.0-192
- binding: handle ovs ofport update (#FD-3063)
[Upstream: 3023dc1932b8ffb4215cf0b2bfe11a600b58f6dd]

* Fri Aug 04 2023 Ales Musil <amusil@redhat.com> - 22.06.0-191
- system-tests: Wait for all interfaces to have IPv6
[Upstream: 20d772bfdd580b397256251c3dad4af382f4c462]

* Fri Aug 04 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-190
- tests: fixed multiple ovn-ic unit tests
[Upstream: fcb0e29db008878867ca55b5196320d6c83b8d50]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-189
- tests: fixed "ARP replies for SNAT external ips"
[Upstream: 70d7ba293d97d0593149add2765feabd0f23b354]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-188
- tests: fixed "ECMP IPv6 symmetric reply"
[Upstream: 86d050e827f026e684dc08b24c581719bb0edb66]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-187
- tests: increased bfd-mult to 15
[Upstream: 393365a1a69cbe7c884117ae47ddeb6b7c1ea306]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-186
- tests: fixed another flake in "send gratuitous ARP for NAT rules on HA distributed router"
[Upstream: f1d2c83f3a5da7d646b85d57d68f40c8664626c0]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-185
- ovn-controller: avoid monitoring wrong chassis
[Upstream: a3638d3230f417d9f5af617a27993df0c3c9323b]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-184
- tests: run system tests also with monitor-all=true
[Upstream: 4b8ff0aebdb91a40e4cc20ebc4d77d83e81a46d9]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-183
- tests: fixed "basic connectivity with multiple requested-chassis"
[Upstream: 2a75c4e28f689ab685c51db07994725ebc0cb0f4]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-182
- tests: fixed flaky "4 HV, 3 LS, 2 LR, packet test with HA distributed router gateway port"
[Upstream: 039a0d85d10909e1ed405ae1bc5aa2be066b71ba]

* Mon Jul 17 2023 Ales Musil <amusil@redhat.com> - 22.06.0-181
- ofctrl-seqno: Do not truncate the last acked value
[Upstream: 03b95a4566a15f7544f4cdf35629dacede4dcf55]

* Fri Jul 14 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-180
- pinctrl: Cap the max size of a prefix delegation DUID value.
[Upstream: 1971125b788563e5b7db4e9ba9d7cb5c05d06675]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-179
- tests: fixed "ovn-controller port security OF flows"
[Upstream: 2febd9ae18618798d39b3664e612260a3f6139b5]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-178
- tests: fixed "ACL Reject ping pong"
[Upstream: 417eafb2245b79d42a8ec816b53d16c6d5eda5f2]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-177
- tests: fixed "nb_cfg timestamp"
[Upstream: 1aba5cde17f729e06e4b50b520859106bc7f6f51]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-176
- tests: fixed "send gratuitous arp for nat ips in localnet"
[Upstream: 268defd3a82f271a55f8f51944521103e4e0341d]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-175
- tests: fixed "check meters update"
[Upstream: 68519b2c81259183feaf201c53ca84fc56256c2f]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-174
- tests: fixed "IPv6 periodic RA"
[Upstream: e08c0709427ae3ece7e66963b76f8a778ac35f0b]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-173
- tests: decreased failure rate of "tug-of-war between two chassis for the same port"
[Upstream: 22543979f211a7a7af8ee651f928a9c8ee36aca9]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-172
- tests: fixed "dhcpv6 : 1 HV, 2 LS, 5 LSPs" and "external logical port"
[Upstream: b8c8c3c7df44564ddf18141c89e79dcd48bbe901]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-171
- tests: fixed "policy-based routing" and "route tables IPv6 -- overlapping subnets"
[Upstream: b7e4172ad75f069f6b2323afb0dc5a10ac15e1c9]

* Fri Jun 16 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-170
- tests: Fix Flaky system-tests "omit connection tracking ..."
[Upstream: 2f2eaba980dc226f23bc26de89fecfc78d3b4742]

* Fri Jun 16 2023 venu iyer <venugopali@nvidia.com> - 22.06.0-169
- northd: bypass connection tracking for stateless flows when there are LB flows present
[Upstream: 2ed9b3931eda99600d4bbe88aafb6f150fb06b04]

* Fri Jun 09 2023 Igor Zhukov <ivzhukov@sbercloud.ru> - 22.06.0-168
- call ovsrcu_exit() before exit in ovn-northd and ovn-controller to make valgrind happy
[Upstream: fa0b475286a3b068b44065e0bb5a84d1b9bfb936]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 22.06.0-167
- northd: Add logical flow to skip GARP with LLA
[Upstream: db86d16a56cf49f61b52c41fb6dd79d0d1c69c66]

* Thu Jun 08 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-166
- northd: match only on supported protocols to handle_svc_check
[Upstream: 1802621dc536fb974aa7d7d12b79fb9bb73369e8]

* Thu Jun 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-165
- tests: Fixed "nested containers" test
[Upstream: 057117238df4a11808c021874b1b0b0b4d6162ad]

* Thu Jun 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-164
- tests: fix flaky Multiple OVS interfaces bound to same logical ports
[Upstream: 6d1352492ead4c3668a9258f62b0c9016f0468f7]

* Tue May 30 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-163
- tests: Fixed load balancing system-tests
[Upstream: a9317666bdca1a15833c06772a7df0f941477cf4]

* Tue May 30 2023 Brian Haley <haleyb.dev@gmail.com> - 22.06.0-162
- controller: Ignore DNS queries with RRs
[Upstream: 6ebbc708614afadb831aef56b04b568765abb0e5]

* Tue May 30 2023 Ales Musil <amusil@redhat.com> - 22.06.0-161
- ci: ovn-kubernetes: Align the timeouts with u/s ovnk
[Upstream: 2463928a642152a9a737553a48b92b531c468640]

* Tue May 30 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-160
- controller: Handle OpenFlow errors.
[Upstream: cad6a918e8572aadb2166439622f458b05bc3aca]

* Tue May 30 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-159
- controller: fix typo in comments
[Upstream: 6538c30e62bf31e169097a19e721b8422978fa8a]

* Tue May 30 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-158
- northd: fix ls_in_hairpin l3dgw flow generation
[Upstream: f8095309547ec0a85121c3c52361ff1de63ee08c]

* Fri May 26 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-157
- ovn-controller.c: Fix assertion failure during address set update.
[Upstream: 0f93d680243da2ee8560a92f0bfa23c6ec4cbaad]

* Fri May 19 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-156
- Pass localnet traffic through CT when a LB is configured.
[Upstream: 65c8fcd93a50bc49bdf0a127c0bd2a911e136329]

* Fri May 19 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-155
- tests: Use stricter IP match for FORMAT_CT.
[Upstream: 21da62ecc872ace1da5a937f31aa80a64253b6a4]

* Wed May 17 2023 Ales Musil <amusil@redhat.com> - 22.06.0-154
- tests: Fix flakiness of policy based routing on slower systems
[Upstream: 7c86f59c4c035271ec2dd36b544f114bdd1388b6]

* Wed May 17 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-153
- ovn-controller docs: fix typo in ovn-monitor-all description
[Upstream: ec81b97169e9b607eecd6cee1fd67d6a96d295f8]

* Tue May 09 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-152
- controller: fix possible unaligned accesses in DHCPv6 code
[Upstream: 8153d7aa72d296c683004b263e02d52297f8c738]

* Mon May 08 2023 Wei Li <liw@yusur.tech> - 22.06.0-151
- documentation: packets that arrive from other chassis resubmit to table 38
[Upstream: 9c7ef4b55fac64187bbaf74360e7e692dfbd85e0]

* Mon May 08 2023 Tao Liu <taoliu828@163.com> - 22.06.0-150
- northd: fix use-after-free after lrp destroyed
[Upstream: 2ba19c38f5e930110321e11fa46885851c1b277b]

* Mon May 08 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-149
- docs: document that vxlan is supported for encap type
[Upstream: ef56e4c6a8a69c2fab53f8efc95761f7c387dcbe]

* Mon May 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-148
- tests: Fixed flaky lr multiple gw ports
[Upstream: b54f458123d7d58ec42c00775a1600e01a0ee6a5]

* Mon May 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-147
- Fix test "load-balancing"
[Upstream: 516fc958b4ff65baa81a793218009e4e23902dae]

* Fri May 05 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-146
- tests: Retry inject-pkt in case ovn-controller is still busy.
[Upstream: da614e657ff27fb9a987ef1a9aa7383016fc50c9]

* Tue May 02 2023 wangchuanlei <wangchuanlei@inspur.com> - 22.06.0-145
- pinctrl: fix restart of controller when bfd min_tx is too low.
[Upstream: fe48eb5c91dedd0185292f5d0abade6d4ccbaa48]

* Tue May 02 2023 Ales Musil <amusil@redhat.com> - 22.06.0-144
- ovn-nbctl: Fix unhandled NULL return from normalize_prefix_str
[Upstream: fdf46831e236da2f7c679bef668224eaab41159f]

* Mon May 01 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-143
- tests: decrease risk of flaky failures of ovn -- CoPP system test
[Upstream: 192ed875042f8e98bb00b38585a39ab5b6db7648]

* Fri Apr 21 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-142
- tests: Skip "daemon ssl files change" when SSL is disabled.
[Upstream: 600b490298bd0ecda64d646e0514ba72eeab37ad]

* Wed Apr 19 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-141
- Omit ACLs for nd || nd_ra || nd_rs || mldv1 || mldv2
[Upstream: b922af2dc84331929ea7e1a3bf56dabd63889c81]

* Wed Apr 19 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-140
- tests: define fmt_pkt function to construct packets with scapy
[Upstream: 4dcfdae8a95dd0ade8b218ab4a847a497065c540]

* Wed Apr 19 2023 Ales Musil <amusil@redhat.com> - 22.06.0-139
- controller: Prevent race in tunnel cleanup
[Upstream: 6ede85eecdf35bda90d724dbf73357c8e70e209d]

* Wed Apr 19 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-138
- nbctl: Display "apply-after-lb" information when listing ACLs.
[Upstream: bdb528f978750f9280d2ebe3305d35f7fb33e8c3]

* Fri Apr 14 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-137
- northd.c: Avoid sending ICMP time exceeded for multicast packets.
[Upstream: b16960317d1b0526cd001805c1e96d4b9a178512]

* Fri Apr 14 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-136
- northd.c: TTL discard flow should support for both ipv4 and ipv6.
[Upstream: 2c4e4c112a8b3e7efd79d53c50c1dc54ae7878d1]

* Tue Apr 11 2023 Ales Musil <amusil@redhat.com> - 22.06.0-135
- northd: Update the is_stateless helper for router nat
[Upstream: 613b2b04d17ea2edabbd0b1a9b93a2628684e1d6]

* Tue Apr 11 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-134
- ci: ovn-kubernetes: Pin ovn-k8s version.
[Upstream: 6257b33014cada0a5aeb1328e6fd67f70e17c9de]

* Tue Apr 11 2023 Eelco Chaudron <echaudro@redhat.com> - 22.06.0-133
- ci: Add arping package to run floating IP tests.
[Upstream: 51301a1cd8d00ea7423e0cce193319fcb2ad4541]

* Tue Apr 11 2023 Ales Musil <amusil@redhat.com> - 22.06.0-132
- controller: Clear tunnels from old integration bridge
[Upstream: ab6c7aecd65b8dcaf2985e44efd9a07d7eae84e4]

* Thu Apr 06 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-131
- northd: take into account qos_min_rate in port_has_qos_params
[Upstream: 30f5ad22f73ea9c2de6a44d6a62e34064ce74f2b]

* Mon Apr 03 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-130
- controller: lflow: do not use tcp as default IP protocol for ct_snat_to_vip action
[Upstream: d4e6bd28b6e8012d6ed7397ce595e20c603310f3]

* Fri Mar 31 2023 Ales Musil <amusil@redhat.com> - 22.06.0-129
- northd: Drop packets for LBs with no backends
[Upstream: 4d1a20c05de841c6b8212659d060b4c3b81d51bc]

* Fri Mar 31 2023 Ales Musil <amusil@redhat.com> - 22.06.0-128
- northd: Make the enclose handling less error prone
[Upstream: 5fc76ab188526c42312c7597b231297d78efa7d4]

* Tue Mar 28 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-127
- northd: do not centralize FIP traffic if redirect-type is set to fixed
[Upstream: d7936963b78edd4eedf93ff717caa53cf68879cf]

* Mon Mar 13 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-126
- tests: Fix incorrect table number in backported test.
[Upstream: 322925d9a6b3b2ba533e449cf14ed8ac9bcd4536]

* Mon Mar 13 2023 Ales Musil <amusil@redhat.com> - 22.06.0-125
- northd: Fix missig "); " from LB flows
[Upstream: 941fdf542792579b43ee3d4baec383b4f2fb25d2]

* Thu Mar 02 2023 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-124
- ovn-util: Remove unused ovn_parse_internal_version_minor.
[Upstream: 03575f05c43e47da0fd3e0fbeb0bc73fab4b9704]

* Thu Mar 02 2023 Ales Musil <amusil@redhat.com> - 22.06.0-123
- system-tests: Reduce flakiness of ACL reject tests
[Upstream: f4f585c8ace73030db4a5c209d36045dbc4e80cf]

* Thu Mar 02 2023 Ales Musil <amusil@redhat.com> - 22.06.0-122
- dbctl: Fix a couple of memory leaks
[Upstream: 996ccd3de513b3f88f03011d54a1db2b69ee7174]

* Thu Mar 02 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-121
- ci: ovn-kubernetes: Bump libovsdb to a6a173993830.
[Upstream: 66b0d98f9b8c31628bb8c6ad6a968956918c76fb]

* Wed Mar 01 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-120
- tests: Fixed some tests failing on (very) slow systems
[Upstream: 7050720ee87583a62d5b03c453efae6af9b02e80]

* Mon Feb 27 2023 Ales Musil <amusil@redhat.com> - 22.06.0-119
- tests: Decrease the number of zones and switches for interconnection
[Upstream: c6b0af2c4a1781899d1c1ed41b676faa670c90f7]

* Wed Feb 15 2023 Ales Musil <amusil@redhat.com> - 22.06.0-118
- system-test: Use OVS_WAIT_UNTIL for tcpdump start instead fo sleep
[Upstream: d1536335eea3bf720e9ebd4e800ce08bd00453fd]

* Wed Feb 15 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-117
- docs: fix the max number of ports per network for vxlan
[Upstream: 9a78548f32f75bdcc7aed6c22c072ae70cfdd0f0]

* Wed Feb 15 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-116
- northd: do not create flows for reserved multicast IPv6 groups
[Upstream: 7634d2638bfc10809ee350065565fea08a7a2e01]

* Thu Feb 02 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-115
- northd.c: Validate port type to avoid unexpected behavior.
[Upstream: 725451d463016b3a743a7015e43a868a1ba45dc5]

* Thu Feb 02 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-114
- tests: Fix flaky test "IPv6 Neighbor Solicitation for unknown MAC"
[Upstream: 0af78b6c7c3d218c49f34623331d4ed79a047efa]

* Thu Feb 02 2023 Felix Hüttner <felix.huettner@mail.schwarz> - 22.06.0-113
- pinctrl: Send RARPs for external ipv6 interfaces
[Upstream: 212966d5f50f28a541b6fe3a0823fe3a70954325]

* Thu Feb 02 2023 Felix Hüttner <felix.huettner@mail.schwarz> - 22.06.0-112
- ovn-macros: support ipv6 in ovn_attach
[Upstream: d772c87b3c154622bb459aa483d9677f96a9fe92]

* Tue Jan 31 2023 Surya Seetharaman <suryaseetharaman.9@gmail.com> - 22.06.0-111
- Add the metalLB install flag for CI actions
[Upstream: 045fea4aa51f98507147cb3719cf3a95c81e03bf]

* Mon Jan 23 2023 Ales Musil <amusil@redhat.com> - 22.06.0-110
- ovn-trace: Use the original ovnact for execute_load
[Upstream: 1b61cc8b98d04ecee9409609ff65b3e4a864395a]

* Mon Jan 23 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-109
- northd: Add logical flows to allow rpl/rel traffic in acl_after_lb stage.
[Upstream: be1e73c8523008a6ea3b461ebbe904089f7cd07b]

* Mon Jan 23 2023 Ales Musil <amusil@redhat.com> - 22.06.0-108
- northd: Add flag for CT related
[Upstream: b57fe49c058dfb0eaf5efeb845f5d220d12ffab3]

* Mon Jan 23 2023 Ales Musil <amusil@redhat.com> - 22.06.0-107
- northd: Store skip_snat and force_snat in ct_label/mark
[Upstream: d2bf5a8f83a2aa59c8eb9d96851135b011ff898c]

* Mon Jan 23 2023 Ales Musil <amusil@redhat.com> - 22.06.0-106
- northd: Add logical flow to defrag ICMP traffic
[Upstream: 67533aa647f635b7e6e0195ff3cb5d6a387e49cd]

* Mon Jan 23 2023 Ales Musil <amusil@redhat.com> - 22.06.0-105
- northd: Allow related traffic through LB
[Upstream: 94b9a4396c0a96d528f6e6824364b00a15135e51]

* Mon Jan 23 2023 Ales Musil <amusil@redhat.com> - 22.06.0-104
- actions: Add new action called ct_commit_nat
[Upstream: 58c9efdccdb4bd7c5e56a14d123c2949d68d6d89]

* Fri Jan 20 2023 Mark Michelson <mmichels@redhat.com> - 22.06.0-103
- ovn-controller: Fix initial requested SNAT zone assignment.
[Upstream: 0c94740caf57f42f2b5966f566b1ffb62ea604e0]

* Wed Jan 18 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-102
- tests: Fixed flaky ACL fair Meters
[Upstream: 9bb8e5333c9c639c0905cfc2ece2bd4ddeaf69a4]

* Wed Jan 18 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-101
- northd: move hairpin stages before acl_after_lb
[Upstream: 9b99d30d4e4c5b7989ea7307f35c6ed75694fc24]

* Tue Jan 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-100
- controller: Fix missing first ping from pod to external
[Upstream: 334bc936841a76a9687254778a16318d26e2b2fa]

* Mon Jan 16 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-99
- controller: use packet proto for hairpin traffic learned action if not specified
[Upstream: ac90cdc527b9e539b0c80ff16468566709e06488]

* Fri Jan 13 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-98
- .ci: ovn-kubernetes: Skip session affinity related tests.
[Upstream: 83e37e8e3bcb9a3c12f079ab60de39d4fb586c8f]

* Fri Jan 13 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-97
- .ci: ovn-kubernetes: Add a "prepare" stage to allow for custom actions.
[Upstream: 5532b938f7abd1068911f86fb52fdb4391d99bb2]

* Wed Jan 11 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-96
- build-aux/sodepends.py: Fix flake8 error.
[Upstream: e42317e538b2c5789392cd8a839972468ba59ecc]

* Wed Jan 11 2023 Han Zhou <hzhou@ovn.org> - 22.06.0-95
- build-aux/sodepends.py: Fix broken build when manpage changes.
[Upstream: 73fc193089bd8eebc9b362b4a183a07620f145c5]

* Wed Jan 11 2023 Dumitru Ceara <dceara@redhat.com> - 22.06.0-94
- ovn-ic: Only monitor useful tables and columns.
[Upstream: 9ba750c19f0ed3b4d85932f5d7f016e973b3edb4]

* Tue Dec 20 2022 Mark Michelson <mmichels@redhat.com> - 22.06.0-93
- Prepare for 22.06.2.
[Upstream: d5be88e44390baed04f3147ef24082270549d255]

* Tue Dec 20 2022 Mark Michelson <mmichels@redhat.com> - 22.06.0-92
- Set release date for 22.06.1.
[Upstream: 8a48c63aba22e6bba1a8f8bc4b33fc315de71d71]

* Fri Dec 16 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-91
- ic: minor code improvements
[Upstream: 9532920107043db93994a713552731c85957e270]

* Fri Dec 16 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-90
- ic: prevent advertising/learning multiple same routes
[Upstream: 6cd865743a1860fa15eec6776861f0fd822b4efd]

* Fri Dec 16 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-89
- ic: lookup southbound port_binding only if needed
[Upstream: 727e61513903d8e4d18c9fc5b278017e3a741674]

* Fri Dec 16 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-88
- ic: remove orphan ovn interconnection routes
[Upstream: 95d14053a36b913cd4beb0886973bb5e737a37e6]

* Wed Dec 14 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-87
- ovn-controller: Only set monitor conditions on available tables.
[Upstream: b0a84c9b283d2017984e9f7f600ea03a22fe20e7]

* Mon Dec 12 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-86
- ovn-trace: Support connecting to SB raft followers.
[Upstream: 7f8318b480eb9578f28f36627edb36191c8df74e]

* Mon Dec 12 2022 Ales Musil <amusil@redhat.com> - 22.06.0-85
- CI: Remove .cirrus.yml
[Upstream: 853171ef00f90295ef37f706ddad577ea8f17eb0]

* Tue Dec 06 2022 Frode Nordahl <frode.nordahl@canonical.com> - 22.06.0-84
- northd: Add missing RBAC rules for BFD table.
[Upstream: 65e86e2bb6b2f67544c023665f2bcb70da033699]

* Tue Dec 06 2022 Frode Nordahl <frode.nordahl@canonical.com> - 22.06.0-83
- ovn-nbctl: Fix removal of BFD entry on route deletion
[Upstream: c0befbe814dc098296a3d3e748b524d01bf40d9d]

* Fri Nov 25 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-82
- controller: Fixed ovs/ovn(features) connection lost when running more than 120 seconds
[Upstream: c6061d58bd0b31aeebef26ca12835d3c4079193f]

* Thu Nov 24 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-81
- ovs: Bump submodule to include latest fixes.
[Upstream: aaad311664481aee0f6e42383c6ab6d603c7dcd4]

* Tue Nov 22 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-80
- ovn-controller: Fixed missing flows after interface deletion
[Upstream: 43a8b1e49306abb0e1bdfc21af2ad77bd1fde343]

* Tue Nov 22 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-79
- ovn-controller: Fix releasing wrong vif
[Upstream: d5aada0accbfbab1fd5753f9ca978841758b79bc]

* Tue Nov 22 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-78
- tests: Fix flaky test "multi-vtep SB Chassis encap updates"
[Upstream: a13cd4d2f75c6b1d58e017f4864ec332906e32f1]

* Fri Nov 18 2022 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-77
- controller: Fix QoS for ports with undetected or too low link speed.
[Upstream: 38127600f9bc8c5393d179588bed6b16216a4f1e]

* Tue Nov 15 2022 Mark Michelson <mmichels@redhat.com> - 22.06.0-76
- ovn-controller: Fix some issues with CT zone assignment.
[Upstream: fda37ecdc23ea5c76ef7a64149ae16006843cece]

* Tue Nov 01 2022 Mohammad Heib <mheib@redhat.com> - 22.06.0-75
- OVN-CI: Add test cases with monitor-all enabled.
[Upstream: 728afe31a0ca2e3093d547abbf69291283dc846f]

* Tue Nov 01 2022 Mohammad Heib <mheib@redhat.com> - 22.06.0-74
- OVN-CI: remove ddlog test cases.
[Upstream: 03f1e2f0e8ec2c04af0156e5074cdc5cc6fcacc0]

* Thu Oct 27 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-73
- tests: Avoid matching on the OVS flow key contents.
[Upstream: af7c01db7dabd0cefedf82e85211f497f11ebdcd]

* Fri Oct 21 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-72
- ovs: Bump submodule to tip of branch-3.0 and add related test
[Upstream: d6b59b35fb4c0bc174e9f1cace4a1b9b244f3c58]

* Fri Oct 21 2022 Ales Musil <amusil@redhat.com> - 22.06.0-71
- ci: Add missing tests after switch to parallel jobs
[Upstream: b04065057cb9e86583368ac6dd04617c9439298d]

* Fri Oct 21 2022 Mohammad Heib <mheib@redhat.com> - 22.06.0-70
- OVN-CI: ovn unit tests run in parallel jobs.
[Upstream: 74a4bcf18b7623f939216f1244d57e1882c93daf]

* Fri Oct 21 2022 Mohammad Heib <mheib@redhat.com> - 22.06.0-69
- CI-Actions: define matrix as a list
[Upstream: 6579dc836f7788bccdf6cea72e6d00e0b7aad866]

* Fri Oct 21 2022 Ales Musil <amusil@redhat.com> - 22.06.0-68
- ci: Use CFLAGS instead of OVS_CFLAGS
[Upstream: ddaa65a20f1c53e0c3667cf23ee6c6453b37c9a5]

* Fri Oct 21 2022 Igor Zhukov <ivzhukov@sbercloud.ru> - 22.06.0-67
- Build tests with asan and ubsan together to reduce CI time.
[Upstream: 89dab07821a2cf3d881bf156ee3071af9ab3e80b]

* Fri Oct 21 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-66
- ci: Add UB Sanitizer.
[Upstream: dc7df1213ed25adbb00e43a2d5626a86b0fbc32c]

* Thu Oct 20 2022 Ales Musil <amusil@redhat.com> - 22.06.0-65
- controller: Add delay after multicast ARP packet
[Upstream: 736734a5c123568019369e40eabc64a0ced10af7]

* Wed Oct 05 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-64
- controller: fix ipv6 prefix delegation in gw router mode
[Upstream: b490c4b9f0f0a215713f440b73ebaca4634b3592]

* Wed Oct 05 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-63
- spec: require python3-openvswitch for ovn-detrace
[Upstream: 51f0f88bd81d8ccefc2b77b9d17138aa27ca3b90]

* Mon Oct 03 2022 Mark Michelson <mmichels@redhat.com> - 22.06.0-62
- northd: Use separate SNAT for already-DNATted traffic.
[Upstream: 6020ed22eafe3741e92dfd150aa98ca3a767ae43]

* Fri Sep 30 2022 Ales Musil <amusil@redhat.com> - 22.06.0-61
- controller: Restore MAC and vlan for DVR scenario
[Upstream: c0a6339f37e09a46bb034070aebd0b8fdd4456fc]

* Fri Sep 30 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-60
- northd: Fix multicast table full
[Upstream: b336ef8dcb860693d5017bf73f489e6a78eb8f97]

* Wed Sep 28 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-59
- ci: ovn-kubernetes: Align CI jobs with recent ovn-kubernetes upstream.
[Upstream: 31b2f6c76ebaa429c79511272277a5796257c43c]

* Wed Sep 28 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-58
- controller: Fix first ping from lsp to external through snat failing
[Upstream: 7ec418f29b37fe76c968d0a581a4defca4815e7e]

* Mon Sep 19 2022 Mark Michelson <mmichels@redhat.com> - 22.06.0-57
- Revert "ovn-controller: fix a crash when deleting a port claimed when sb was ro"
[Upstream: 981b87f0450cda3532e42329994178a5cca9d09b]

* Fri Sep 16 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-56
- ovn-controller: fix a crash when deleting a port claimed when sb was ro
[Upstream: 25152000923af1b1c35fd2d758dcc8564c158c42]

* Fri Sep 16 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-55
- northd: drop traffic to disabled LSPs in ingress pipeline
[Upstream: 167a7bf1a0838ecbf0617fe0856ba9087df2337b]

* Fri Sep 16 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-54
- controller: flush associated conntrack zone on PB release
[Upstream: adb79f2838ce37fdd237d54a73bf9955b2df52c5]

* Fri Sep 16 2022 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-53
- northd: Re-use IP sets created for load balancer groups.
[Upstream: 23676602ce71e0fc160c4691bcc748c197a073e9]

* Fri Sep 16 2022 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-52
- northd: Retrieve load balancer options only once.
[Upstream: 7de8774e5aa8cf07e49c483ce3f1e729ad135d06]

* Fri Sep 16 2022 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-51
- northd: Add datapaths to load balancers in bulk.
[Upstream: 12d9780ab01d97c6d6f80af8533400f4209f7457]

* Fri Sep 16 2022 Ilya Maximets <i.maximets@ovn.org> - 22.06.0-50
- northd: Optimize load balancer lookups for groups.
[Upstream: c0fa05571b30db0760ba9f38b884c8d97d77f865]

* Fri Sep 16 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-49
- Bump required python version to 3.6.
[Upstream: 65c9911ed6c8a2575b205b11afd1679f487ca204]

* Fri Sep 16 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-48
- tests: Fix tests/check_acl_log.py outputs.
[Upstream: a553f2716cf068478bd50192a3bff6e4eeef9aff]

* Thu Sep 15 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-47
- northd: don't include disabled LSP's IP to Load Balancing
[Upstream: 75f2fe197569362f6cd86d05c72e4f75f11447d0]

* Fri Sep 09 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-46
- tests: Factor out reset_pcap_file() helper.
[Upstream: f4c7a4223abe7129234bd4568e9f2a75b4800d2b]

* Thu Sep 08 2022 Han Zhou <hzhou@ovn.org> - 22.06.0-45
- Don't blindly save original dst IP and Port to avoid megaflow unwildcarding.
[Upstream: fe9fc89961ea893755cfcd613703d03785b9bf48]

* Mon Aug 29 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-44
- controller: fix potential segmentation violation when removing ports
[Upstream: b89b96e1a16134c0aa8cd6513d920d49ff8c6cda]

* Fri Aug 19 2022 Mohammad Heib <mheib@redhat.com> - 22.06.0-43
- binding.c: update ld->peers when lsp type updated
[Upstream: 978c1db7e1678d69be0f69e2c7ced3e96a0f7488]

* Fri Aug 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-42
- northd: rely on new actions for ecmp-symmetric routing
[Upstream: 8434cdd06cac1d16f7140b39862cdf826ea9174b]

* Fri Aug 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-41
- actions: introduce chk_ecmp_nh and chk_ecmp_nh_mac actions
[Upstream: c1b2251563b47075d29dfbc5a37278e11c5f8090]

* Fri Aug 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-40
- actions: introduce commit_ecmp_nh action
[Upstream: fbe3da470f7631169eb6987ee7c1050bbcadffdf]

* Thu Aug 18 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-39
- github: ovn-kubernetes: Update go, kube and libovsdb versions.
[Upstream: 959e035ca12f98818595d0e2442610f4f0ba907c]

* Thu Aug 18 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-38
- controller: physical: fix regression for container ports
[Upstream: 5e2baaa4402b7cf600c4822c7b6c1bae89badaf1]

* Wed Aug 17 2022 Olaf Seibert <o.seibert@syseleven.de> - 22.06.0-37
- northd: Fix memory leak.
[Upstream: d9a050e0c9f2e09f8066879809aa96acf6544347]

* Wed Aug 17 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-36
- controller: throttle port claim attempts
[Upstream: 8f1d63bbf6f67ab2bc4eb3d59ba1de43a4f6548f]

* Wed Aug 17 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-35
- Split out code to handle port binding db updates
[Upstream: 3171d0ce474eb90c89cbd2b2e4ed7c885195bba4]

* Tue Aug 09 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-34
- northd: Do not relay local IP multicast (224.0.0.X).
[Upstream: 5ad79df0229ff190687225a06df73a50d2100f50]

* Mon Aug 08 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-33
- tests: Enable vif-plug tests and fix the vif-provider.
[Upstream: 1293b7f0fb6854cdc0a6a7d760a444db28df1212]

* Mon Aug 08 2022 Ales Musil <amusil@redhat.com> - 22.06.0-32
- ovn-ctl: Ensure that log/run directory have correct permission
[Upstream: e9da1112d171063c9a8cee417105b65cb85e233d]

* Fri Aug 05 2022 Han Zhou <hzhou@ovn.org> - 22.06.0-31
- ofctrl.c: mff_ovn_geneve should be available at state WAIT_BEFORE_CLEAR.
[Upstream: d6a8d9eb1579aa1542540e51ae7c53e84e9616d7]

* Tue Aug 02 2022 Ales Musil <amusil@redhat.com> - 22.06.0-30
- controller: Fix IPv6 prefix delegation
[Upstream: 910523a0b9fc1e5da04ca8d954b03c4f0e641e53]

* Tue Aug 02 2022 Ales Musil <amusil@redhat.com> - 22.06.0-29
- system-tests: Reduce flakiness of IPv6 prefix delegation
[Upstream: fe639323b3911f2a99e495c3fcf6ea3c18654066]

* Tue Aug 02 2022 Mohammad Heib <mheib@redhat.com> - 22.06.0-28
- northd: handle virtual lport type update
[Upstream: 367dda01b9fcaab15079fd3dc1418353890745a6]

* Thu Jul 28 2022 Han Zhou <hzhou@ovn.org> - 22.06.0-27
- extend-table: Fix table ID double allocation after OVS restart.
[Upstream: 3affdfe8952fa359ed52aa0cbb28ffb879ba6fb6]

* Sat Jul 23 2022 Andreas Karis <ak.karis@gmail.com> - 22.06.0-26
- IPsec: Add option to force NAT-T encapsulation
[Upstream: 0e3ee19efea923ca6293af12e6610460c0cfb8b8]

* Thu Jul 21 2022 Numan Siddique <numans@ovn.org> - 22.06.0-25
- Fix compilation issue in fedora 37/rawhide.
[Upstream: 5f948fc8f99fc12fc666ffe1ee4b54e005ff7038]

* Tue Jul 19 2022 wangchuanlei <wangchuanlei@inspur.com> - 22.06.0-24
- pinctrl: fix ovn-controller abort when service start.
[Upstream: 593b3c25e1ab88db3e13fe93c8a265e7efea3863]

* Tue Jul 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-23
- lflow: fix possible use-after-free in add_lb_vip_hairpin_reply_action
[Upstream: 6bcb3b7931c3e705c9d2ff0235accc0575cfbc7b]

* Tue Jul 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-22
- ovn-ic: do not learn routes with link-local next-hops
[Upstream: 55d2f0c805ef912aab5483fed384e2b749fbe413]

* Tue Jul 12 2022 Xavier Simonart <xsimonar@redhat.com> - 22.06.0-21
- tests: fixed flaky test localnet connectivity with multiple requested-chassis
[Upstream: 592ba5643c5e250e0f2fd0232d475cee1a3e2014]

* Mon Jul 11 2022 Dumitru Ceara <dceara@redhat.com> - 22.06.0-20
- ovn-nb: Properly document multicast flood config defaults.
[Upstream: 503e7333efc193fd8457f981e32d48ec27c417df]

* Mon Jul 11 2022 Ales Musil <amusil@redhat.com> - 22.06.0-19
- ovn-nbctl: Fix priority arg of lrp-set-gateway-chassis
[Upstream: bc46ab4dbdd866307ce4851fc68170764625f397]

* Mon Jul 11 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-18
- Always funnel multichassis port traffic through tunnels
[Upstream: 894bcac4922928eb5701bdeb0fd8319973fd3ba6]

* Thu Jul 07 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.06.0-17
- northd: set svc_mon status to offline if port_binding released
[Upstream: 8cc90ac02fff34d640c551230c712f9184d35e2a]

* Fri Jul 01 2022 Mark Michelson <mmichels@redhat.com> - 22.06.0-16
- ovs: Bump submodule to newer version
[Upstream: 5593044a8be0d2ce730e4890cf213ee760916889]

* Wed Jun 29 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-15
- tests: add multi-chassis keyword to relevant test cases
[Upstream: 4bdade3593ae3c6604822716d22ab04b0af962da]

* Wed Jun 29 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.06.0-14
- northd: add condition for stateless nat drop flow in S_ROUTER_IN_GW_REDIRECT pipeline
[Upstream: 9885154fc41005dbb8fbbdca9e3a38d892870f53]

* Wed Jun 29 2022 Ales Musil <amusil@redhat.com> - 22.06.0-13
- northd.c: Add flow to skip put_nd action if ip6.src or nd.sll is 0
[Upstream: c5596102cb84e22086d7807b31cbe5c9e893ac38]

* Wed Jun 29 2022 Terry Wilson <twilson@redhat.com> - 22.06.0-12
- Allow arbitrary args to be passed to called binary
[Upstream: 849106f6ee75d7b1ff990763325d41d45c843a64]

* Mon Jun 27 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-11
- tests: ovn-nbctl dump-flows -> ovn-sbctl dump-flows
[Upstream: 656a91b6b5cd9d9e48b8e938fcffb81ead2d9fda]

* Mon Jun 27 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-10
- Fix memleak in ovn-nbctl when args can't be parsed
[Upstream: 70b360325c13f399835b1f5c7ac0c0acd4832773]

* Mon Jun 20 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-9
- Implement RARP activation strategy for ports
[Upstream: c75ddaf804cc8ea8499706430b438ae53f2f1224]

* Tue Jun 14 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-8
- Fix pidfile_is_running when $cmd is not passed
[Upstream: 44e047d6f1be5ae4f564e82a928cf1f08f1908ef]

* Thu Jun 09 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.06.0-7
- Lock pinctrl_mutex for pinctrl_wait
[Upstream: 6e36ad7a52ec4e6443ccb3185bda6421cdf6747e]

* Thu Jun 09 2022 Terry Wilson <twilson@redhat.com> - 22.06.0-6
- Ensure pid belongs to ovsdb-server in ovn-ctl
[Upstream: d0847f56913245c19a33e087f730c084ca674c83]

* Thu Jun 09 2022 Terry Wilson <twilson@redhat.com> - 22.06.0-5
- Handle re-used pids in pidfile_is_running
[Upstream: 98e7d4b3675b237c770763377382075ac08c64ba]

* Fri Jun 03 2022 Mark Michelson <mmichels@redhat.com> - 22.06.0-4
- Prepare for 22.06.1.
[Upstream: 437dc3a01266d7f128bba532c674c5827af1bd6f]

